==> better-admin-ui-vue-0.0.2.tgz: package/es/components/DictSelect/DictSelect.js <==
import * as _vue from "vue";
import { DictSelectProps } from './types';
import isPromise from 'is-promise';
import ASelect from 'ant-design-vue/es/select';
import './style.less';
/**
 *  字典列表的下拉选择框
 */

export default {
  name: 'EDictSelect',
  components: {
    ASelect: ASelect
  },
  props: DictSelectProps,
  data: function data() {
    return {
      // 待下拉数据是否准备完毕
      dataReady: false,
      // 待下拉数据集合
      list: [],
      // 选中的项数据
      selectedValue: undefined
    };
  },
  // 数据双向绑定，定义props的value为双向绑定属性，同时定义selected为抛出事件
  model: {
    props: 'value',
    event: 'selected'
  },
  computed: {
    text: function text() {
      var _this = this;

      var i = this.$data.list && this.$data.list.findIndex(function (item) {
        return item.value === _this.$props.value;
      });

      if (i !== -1) {
        return this.$data.list[i].label;
      } else {
        return '';
      }
    }
  },
  watch: {
    value: function value(newVal) {
      this.$data.selectedValue = newVal;
    }
  },
  created: function created() {
    this.$data.selectedValue = this.$props.value || undefined;
  },
  mounted: function mounted() {
    this._initOptionList();
  },
  methods: {
    /**
     * 初始化选项数据
     * @private
     */
    _initOptionList: function _initOptionList() {
      if (this.$props.options && this.$props.options.length > 0) {
        this.$data.list = this.$props.options;
        this.dataReady = true;
      } else if (this.$props.itemId) {
        this._getItemListByItemID();
      } else {
        this.dataReady = false;
        console.warn('DictSelect传入的数据为空');
      }
    },

    /**
     * 根据字典组id获取字典列表。此方法需要在Vue.use挂载组件的时候被覆盖
     */
    getDictList: function getDictList() {},

    /**
     * 根据字典组ID获取字典列表
     * @private
     */
    _getItemListByItemID: function _getItemListByItemID() {
      var _this2 = this;

      var result = this.getDictList(this.$props.itemId);

      if (isPromise(result)) {
        result.then(function (list) {
          _this2.$data.list = list.map(function (item) {
            return {
              label: item.caption,
              value: item.name
            };
          });
          _this2.dataReady = true;
        })["catch"](function () {
          _this2.dataReady = false;
        });
      }
    },

    /**
     * 渲染可编辑的节点
     * @return {JSX.Element}
     * @private
     */
    _renderEditable: function _renderEditable() {
      var _this3 = this;

      return _vue.createVNode(_vue.resolveComponent("a-select"), {
        "options": this.$data.list,
        "modelValue": _this3.$data.selectedValue,
        "onUpdate:modelValue": function onUpdateModelValue($event) {
          return _this3.$data.selectedValue = $event;
        },
        "disabled": this.$props.disabled,
        "onSelect": function onSelect(value) {
          _this3.$emit('selected', value);
        },
        "placeholder": this.$props.placeholder
      }, null);
    },

    /**
     * 渲染不可编辑的节点
     * @return {JSX.Element}
     * @private
     */
    _renderReadOnly: function _renderReadOnly() {
      return _vue.createVNode("div", {
        "style": "line-height:30px;"
      }, [this.text]);
    }
  },
  render: function render() {
    return this.$data.dataReady ? _vue.createVNode("div", {
      "class": "dict-select"
    }, [this.$props.editable ? this._renderEditable() : this._renderReadOnly()]) : null;
  }
};

==> better-admin-ui-vue-0.0.4.tgz: package/es/components/DictSelect/DictSelect.js <==
import { DictSelectProps } from './types';
import isPromise from 'is-promise';
import ASelect from 'ant-design-vue/es/select';
import './style.less';
/**
 *  字典列表的下拉选择框
 */

export default {
  name: 'EDictSelect',
  props: DictSelectProps,
  data: function data() {
    return {
      // 待下拉数据是否准备完毕
      dataReady: false,
      // 待下拉数据集合
      list: [],
      // 选中的项数据
      selectedValue: undefined
    };
  },
  // 数据双向绑定，定义props的value为双向绑定属性，同时定义selected为抛出事件
  model: {
    props: 'value',
    event: 'selected'
  },
  computed: {
    text: function text() {
      var _this = this;

      var i = this.$data.list && this.$data.list.findIndex(function (item) {
        return item.value === _this.$props.value;
      });

      if (i !== -1) {
        return this.$data.list[i].label;
      } else {
        return '';
      }
    }
  },
  watch: {
    value: function value(newVal) {
      this.$data.selectedValue = newVal;
    }
  },
  created: function created() {
    this.$data.selectedValue = this.$props.value || undefined;
  },
  mounted: function mounted() {
    this._initOptionList();
  },
  methods: {
    /**
     * 初始化选项数据
     * @private
     */
    _initOptionList: function _initOptionList() {
      if (this.$props.options && this.$props.options.length > 0) {
        this.$data.list = this.$props.options;
        this.dataReady = true;
      } else if (this.$props.itemId) {
        this._getItemListByItemID();
      } else {
        this.dataReady = false;
        console.warn('DictSelect传入的数据为空');
      }
    },

    /**
     * 根据字典组id获取字典列表。此方法需要在Vue.use挂载组件的时候被覆盖
     */
    getDictList: function getDictList() {},

    /**
     * 根据字典组ID获取字典列表
     * @private
     */
    _getItemListByItemID: function _getItemListByItemID() {
      var _this2 = this;

      var result = this.getDictList(this.$props.itemId);

      if (isPromise(result)) {
        result.then(function (list) {
          _this2.$data.list = list.map(function (item) {
            return {
              label: item.caption,
              value: item.name
            };
          });
          _this2.dataReady = true;
        })["catch"](function () {
          _this2.dataReady = false;
        });
      }
    },

    /**
     * 渲染可编辑的节点
     * @return {JSX.Element}
     * @private
     */
    _renderEditable: function _renderEditable() {
      var _this3 = this;

      var h = this.$createElement;
      return h(ASelect, {
        attrs: {
          options: this.$data.list,
          vModel: this.$data.selectedValue,
          disabled: this.$props.disabled,
          placeholder: this.$props.placeholder
        },
        on: {
          "select": function select(value) {
            _this3.$emit('selected', value);
          }
        }
      });
    },

    /**
     * 渲染不可编辑的节点
     * @return {JSX.Element}
     * @private
     */
    _renderReadOnly: function _renderReadOnly() {
      var h = this.$createElement;
      return h("div", {
        style: "line-height:30px;"
      }, [this.text]);
    }
  },
  render: function render() {
    var h = arguments[0];
    return this.$data.dataReady ? h("div", {
      "class": "dict-select"
    }, [this.$props.editable ? this._renderEditable() : this._renderReadOnly()]) : null;
  }
};
